aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/compiler/xla/literal_util.h
diff options
context:
space:
mode:
authorGravatar Eli Bendersky <eliben@google.com>2017-11-29 16:12:31 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2017-11-29 16:15:53 -0800
commitbc7180f02002788a7b57b36b14ceb7a47d6c76f4 (patch)
treee6e0833b89a61850b433db1a1dfe7f661e230753 /tensorflow/compiler/xla/literal_util.h
parent963a521e255d2a189e349fc5c24ebc2bc032be5b (diff)
Fix more clang-tidy warnings:
- Parameter names consistent in function declarations and definitions - Class members naming PiperOrigin-RevId: 177379085
Diffstat (limited to 'tensorflow/compiler/xla/literal_util.h')
-rw-r--r--tensorflow/compiler/xla/literal_util.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tensorflow/compiler/xla/literal_util.h b/tensorflow/compiler/xla/literal_util.h
index f37e529caf..069d1b33ca 100644
--- a/tensorflow/compiler/xla/literal_util.h
+++ b/tensorflow/compiler/xla/literal_util.h
@@ -285,11 +285,11 @@ class Literal {
std::unique_ptr<Literal> Relayout(const Layout& new_layout,
const ShapeIndex& shape_index = {}) const;
// Creates a new literal by reshaping this literal to have 'shape'. Both the
// original shape and 'shape' must contain the same number of elements. The
// implementation currently only supports monotonic dim0-major layouts.
StatusOr<std::unique_ptr<Literal>> Reshape(
- tensorflow::gtl::ArraySlice<int64> shape) const;
+ tensorflow::gtl::ArraySlice<int64> dimensions) const;
// Creates a new literal by reordering the dimensions of this literal.
// The given `permutation` must be a permutation of the dimension numbers
@@ -285,11 +285,11 @@ class Literal {
std::unique_ptr<Literal> Relayout(const Layout& new_layout,
const ShapeIndex& shape_index = {}) const;
- // Creates a new literal by reshaping this literal to have 'shape'. Both the
- // original shape and 'shape' must contain the same number of elements. The
+ // Creates a new literal by reshaping this literal to have the given
+ // dimensions. The total number of elements must not change; The
// implementation currently only supports monotonic dim0-major layouts.
StatusOr<std::unique_ptr<Literal>> Reshape(